# Python Client for the Almond API

[![Build Status](https://travis-ci.com/stanford-oval/pyalmond.svg?branch=master)](https://travis-ci.com/stanford-oval/pyalmond) [![Coverage Status](https://coveralls.io/repos/github/stanford-oval/pyalmond/badge.svg?branch=master)](https://coveralls.io/github/stanford-oval/pyalmond?branch=master) [![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/stanford-oval/pyalmond.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/stanford-oval/pyalmond/context:python)

This package contains a Python client to access the [Almond API](https://almond.stanford.edu/doc/my-api.md).
It allows to communicate and control a running Almond instance from a Python application.

## Installation

To install this package, run:

```bash
pip3 install --user pyalmond
```

## Developer Setup

The developer dependencies are listed in requirements.txt. You can install them with:
```bash
pip3 install -r requirements.txt
```